==================
ulaval-notify
==================

:Author: `Antoine Gagné <antoine.gagne.2@ulaval.ca>`_

.. contents::
    :backlinks: none

.. sectnum::

Requirements
============

To install this program, you must have the following:

- ``python 3.6+``

Installation
============

To install this program, you can simply run the following command:

::

    python setup.py install
